Documentation
¶
Overview ¶
Package v1alpha1 contains useful functionality or struct for template
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Template ¶
type Template struct {
// Name is the name of the Template
// If not empty, must be unique in the list of templates
// +optional
Name string `json:"name,omitempty"`
// ResolverRef can be used to refer to a Resource in a remote
// location like a git repo.
TemplateRef pipev1beta1.ResolverRef `json:"templateRef,omitempty"`
// Params define a list of parameters for the Template
// +optional
Params []pipev1beta1.Param `json:"params,omitempty"`
// Metadata contains the name labels and annotations for template
// This information will be automatically populated when obtaining it
// without the need for the user to configure it actively.
// +optional
Metadata v1alpha1.Metadata `json:"metadata,omitempty"`
}
Template defines the desired state of Template
func (*Template) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Template.
func (*Template) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
Click to show internal directories.
Click to hide internal directories.